@@ -120,8 +120,8 @@ class FluidNexusDatabase(object):
         """Add some dummy data to the database."""
         # Insert some dummy data
         # This is from text messages listed in the TxTMob CHI paper
-        title = u'Run'
-        content = u'[SAMPLE MESSAGE] Run against Bush in progress (just went through times sq).  media march starts at 7, 52nd and broadway'
+        title = u'Message One to send'
+        content = u'[SAMPLE MESSAGE] Some sort of message to send to others.'
         now = time.time()
         message_hash = hashlib.sha256(title + content).hexdigest()
         data = {}
@@ -132,8 +132,8 @@ class FluidNexusDatabase(object):
         data["message_hash"] = message_hash
         self.addMine(data = data)
 
-        title = u'Federal agents'
-        content = u'[SAMPLE MESSAGE] Video dispatch. Federal agents trailing activists at 6th Ave and 9th St. Situation tense.'
+        title = u'A sample message'
+        content = u'[SAMPLE MESSAGE] A message with some sort of content.'
         message_hash = hashlib.sha256(title + content).hexdigest()
         now = time.time()
         data["message_title"] = title
@@ -143,8 +143,8 @@ class FluidNexusDatabase(object):
         data["message_hash"] = message_hash
         self.addReceived(data = data)
 
-        title = u'Mobilize to dine'
-        content = u'[SAMPLE MESSAGE] CT delegation @ Maison (7th Ave. & 53rd).  Outdoor dining area.  Try to get people there.'
+        title = u'Testing'
+        content = u'[SAMPLE MESSAGE] Just a test.'
         message_hash = hashlib.sha256(title + content).hexdigest()
         now = time.time()
         data["message_title"] = title
